@@ -16,14 +16,12 @@
 #include "kactioncollection.h"
 
 #include <QAction>
-#include <QKeyEvent>
-#include <QTimer>
-#include <QHash>
-#include <QHBoxLayout>
-#include <QToolButton>
 #include <QApplication>
+#include <QHBoxLayout>
+#include <QHash>
+#include <QToolButton>
 
-#include <KeySequenceRecorder>
+#include <KKeySequenceRecorder>
 #include <KLocalizedString>
 #include <KMessageBox>
 #if HAVE_GLOBALACCEL
@@ -41,8 +39,8 @@ static bool shortcutsConflictWith(const QList<QKeySequence> &shortcuts, const QK
             continue;
         }
 
-        if (sequence.matches(needle) != QKeySequence::NoMatch
-                || needle.matches(sequence) != QKeySequence::NoMatch) {
+        if (sequence.matches(needle) != QKeySequence::NoMatch //
+            || needle.matches(sequence) != QKeySequence::NoMatch) {
             return true;
         }
     }
@@ -50,18 +48,17 @@ static bool shortcutsConflictWith(const QList<QKeySequence> &shortcuts, const QK
     return false;
 }
 
-
 class KKeySequenceWidgetPrivate
 {
 public:
-    KKeySequenceWidgetPrivate(KKeySequenceWidget *q);
+    KKeySequenceWidgetPrivate(KKeySequenceWidget *qq);
 
     void init();
 
     void updateShortcutDisplay();
     void startRecording();
 
-    //Conflicts the key sequence @p seq with a current standard shortcut?
+    // Conflicts the key sequence @p seq with a current standard shortcut?
     bool conflictWithStandardShortcuts(const QKeySequence &seq);
     // Conflicts the key sequence @p seq with a current local shortcut?
     bool conflictWithLocalShortcuts(const QKeySequence &seq);
@@ -70,8 +67,13 @@ public:
 
     bool promptStealLocalShortcut(const QList<QAction *> &actions, const QKeySequence &seq);
     bool promptstealStandardShortcut(KStandardShortcut::StandardShortcut std, const QKeySequence &seq);
+
 #if HAVE_GLOBALACCEL
-    bool promptStealGlobalShortcut(const QHash<QKeySequence, QList<KGlobalShortcutInfo> > &shortcuts, const QKeySequence &sequence);
+    struct KeyConflictInfo {
+        QKeySequence key;
+        QList<KGlobalShortcutInfo> shortcutInfo;
+    };
+    bool promptStealGlobalShortcut(const std::vector<KeyConflictInfo> &shortcuts, const QKeySequence &sequence);
 #endif
     void wontStealShortcut(QAction *item, const QKeySequence &seq);
 
@@ -90,12 +92,12 @@ public:
         return checkAgainstShortcutTypes & KKeySequenceWidget::LocalShortcuts;
     }
 
-//private slot
+    // private slot
     void doneRecording();
 
-//members
+    // members
     KKeySequenceWidget *const q;
-    KeySequenceRecorder *recorder;
+    KKeySequenceRecorder *recorder;
     QHBoxLayout *layout;
     QPushButton *keyButton;
     QToolButton *clearButton;
@@ -107,11 +109,6 @@ public:
     //! Check the key sequence against KStandardShortcut::find()
     KKeySequenceWidget::ShortcutTypes checkAgainstShortcutTypes;
 
-    /**
-     * The list of action to check against for conflict shortcut
-     */
-    QList<QAction *> checkList; // deprecated
-
     /**
      * The list of action collections to check against for conflict shortcut
      */
@@ -123,15 +120,16 @@ public:
     QList<QAction *> stealActions;
 };
 
-KKeySequenceWidgetPrivate::KKeySequenceWidgetPrivate(KKeySequenceWidget *q)
-    : q(q)
+KKeySequenceWidgetPrivate::KKeySequenceWidgetPrivate(KKeySequenceWidget *qq)
+    : q(qq)
     , layout(nullptr)
     , keyButton(nullptr)
     , clearButton(nullptr)
     , componentName()
     , checkAgainstShortcutTypes(KKeySequenceWidget::LocalShortcuts | KKeySequenceWidget::GlobalShortcuts)
     , stealActions()
-{}
+{
+}
 
 void KKeySequenceWidgetPrivate::init()
 {
@@ -141,7 +139,9 @@ void KKeySequenceWidgetPrivate::init()
     keyButton = new QPushButton(q);
     keyButton->setFocusPolicy(Qt::StrongFocus);
     keyButton->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
-    keyButton->setToolTip(i18nc("@info:tooltip", "Click on the button, then enter the shortcut like you would in the program.\nExample for Ctrl+A: hold the Ctrl key and press A."));
+    keyButton->setToolTip(
+        i18nc("@info:tooltip",
+              "Click on the button, then enter the shortcut like you would in the program.\nExample for Ctrl+A: hold the Ctrl key and press A."));
     layout->addWidget(keyButton);
 
     clearButton = new QToolButton(q);
@@ -153,7 +153,7 @@ void KKeySequenceWidgetPrivate::init()
         clearButton->setIcon(QIcon::fromTheme(QStringLiteral("edit-clear-locationbar-ltr")));
     }
 
-    recorder = new KeySequenceRecorder(q->window()->windowHandle(), q);
+    recorder = new KKeySequenceRecorder(q->window()->windowHandle(), q);
     recorder->setModifierlessAllowed(false);
     recorder->setMultiKeyShortcutsAllowed(true);
 
@@ -162,7 +162,6 @@ void KKeySequenceWidgetPrivate::init()
 
 bool KKeySequenceWidgetPrivate::promptStealLocalShortcut(const QList<QAction *> &actions, const QKeySequence &seq)
 {
-
     const int listSize = actions.size();
 
     QString title = i18ncp("%1 is the number of conflicts", "Shortcut Conflict", "Shortcut Conflicts", listSize);
@@ -173,7 +172,7 @@ bool KKeySequenceWidgetPrivate::promptStealLocalShortcut(const QList<QAction *>
                                      action->shortcut().toString(QKeySequence::NativeText),
                                      KLocalizedString::removeAcceleratorMarker(action->text()));
     }
-    QString message = i18ncp("%1 is the number of ambigious shortcut clashes (hidden)",
+    QString message = i18ncp("%1 is the number of ambiguous shortcut clashes (hidden)",
                              "The \"%2\" shortcut is ambiguous with the following shortcut.\n"
                              "Do you want to assign an empty shortcut to this action?\n"
                              "%3",
@@ -184,16 +183,18 @@ bool KKeySequenceWidgetPrivate::promptStealLocalShortcut(const QList<QAction *>
                              seq.toString(QKeySequence::NativeText),
                              conflictingShortcuts);
 
-   return KMessageBox::warningContinueCancel(q, message, title, KGuiItem(i18nc("@action:button", "Reassign"))) == KMessageBox::Continue;
+    return KMessageBox::warningContinueCancel(q, message, title, KGuiItem(i18nc("@action:button", "Reassign"))) == KMessageBox::Continue;
 }
 
 void KKeySequenceWidgetPrivate::wontStealShortcut(QAction *item, const QKeySequence &seq)
 {
     QString title(i18nc("@title:window", "Shortcut conflict"));
-    QString msg(i18n("<qt>The '%1' key combination is already used by the <b>%2</b> action.<br>"
-                     "Please select a different one.</qt>", seq.toString(QKeySequence::NativeText),
-                     KLocalizedString::removeAcceleratorMarker(item->text())));
-    KMessageBox::sorry(q, msg, title);
+    QString msg(
+        i18n("<qt>The '%1' key combination is already used by the <b>%2</b> action.<br>"
+             "Please select a different one.</qt>",
+             seq.toString(QKeySequence::NativeText),
+             KLocalizedString::removeAcceleratorMarker(item->text())));
+    KMessageBox::error(q, msg, title);
 }
 
 bool KKeySequenceWidgetPrivate::conflictWithLocalShortcuts(const QKeySequence &keySequence)
@@ -202,16 +203,14 @@ bool KKeySequenceWidgetPrivate::conflictWithLocalShortcuts(const QKeySequence &k
         return false;
     }
 
-    // We have actions both in the deprecated checkList and the
-    // checkActionCollections list. Add all the actions to a single list to
+    // Add all the actions from the checkActionCollections list to a single list to
     // be able to process them in a single loop below.
     // Note that this can't be done in setCheckActionCollections(), because we
     // keep pointers to the action collections, and between the call to
     // setCheckActionCollections() and this function some actions might already be
     // removed from the collection again.
     QList<QAction *> allActions;
-    allActions += checkList;
-    for (KActionCollection *collection : qAsConst(checkActionCollections)) {
+    for (KActionCollection *collection : std::as_const(checkActionCollections)) {
         allActions += collection->actions();
     }
 
@@ -234,12 +233,12 @@ bool KKeySequenceWidgetPrivate::conflictWithLocalShortcuts(const QKeySequence &k
     // 1/2/3 key shortcuts. I think you can imagine.
     QList<QAction *> conflictingActions;
 
-    //find conflicting shortcuts with existing actions
-    for (QAction *qaction : qAsConst(allActions)) {
+    // find conflicting shortcuts with existing actions
+    for (QAction *qaction : std::as_const(allActions)) {
         if (shortcutsConflictWith(qaction->shortcuts(), keySequence)) {
             // A conflict with a KAction. If that action is configurable
             // ask the user what to do. If not reject this keySequence.
-            if (checkActionCollections.first()->isShortcutsConfigurable(qaction)) {
+            if (KActionCollection::isShortcutsConfigurable(qaction)) {
                 conflictingActions.append(qaction);
             } else {
                 wontStealShortcut(qaction, keySequence);
@@ -253,11 +252,10 @@ bool KKeySequenceWidgetPrivate::conflictWithLocalShortcuts(const QKeySequence &k
         return false;
     }
 
-
     if (promptStealLocalShortcut(conflictingActions, keySequence)) {
         stealActions = conflictingActions;
         // Announce that the user agreed
-        for (QAction *stealAction : qAsConst(stealActions)) {
+        for (QAction *stealAction : std::as_const(stealActions)) {
             Q_EMIT q->stealShortcut(keySequence, stealAction);
         }
         return false;
@@ -266,61 +264,65 @@ bool KKeySequenceWidgetPrivate::conflictWithLocalShortcuts(const QKeySequence &k
 }
 
 #if HAVE_GLOBALACCEL
-bool KKeySequenceWidgetPrivate::promptStealGlobalShortcut(const QHash<QKeySequence, QList<KGlobalShortcutInfo> > &clashing, const QKeySequence &sequence)
+bool KKeySequenceWidgetPrivate::promptStealGlobalShortcut(const std::vector<KeyConflictInfo> &clashing, const QKeySequence &sequence)
 {
     QString clashingKeys;
-    for (auto it = clashing.begin(); it != clashing.end(); ++it) {
-        const auto seqAsString = it.key().toString();
-        for (const KGlobalShortcutInfo &info : it.value()) {
-            clashingKeys += i18n("Shortcut '%1' in Application %2 for action %3\n",
-                                    seqAsString, info.componentFriendlyName(), info.friendlyName());
+    for (const auto &[key, shortcutInfo] : clashing) {
+        const QString seqAsString = key.toString();
+        for (const KGlobalShortcutInfo &info : shortcutInfo) {
+            clashingKeys += i18n("Shortcut '%1' in Application '%2' for action '%3'\n", //
+                                 seqAsString,
+                                 info.componentFriendlyName(),
+                                 info.friendlyName());
         }
     }
     const int hashSize = clashing.size();
 
     QString message = i18ncp("%1 is the number of conflicts (hidden), %2 is the key sequence of the shortcut that is problematic",
-                                "The shortcut '%2' conflicts with the following key combination:\n",
-                                "The shortcut '%2' conflicts with the following key combinations:\n",
-                                hashSize, sequence.toString());
+                             "The shortcut '%2' conflicts with the following key combination:\n",
+                             "The shortcut '%2' conflicts with the following key combinations:\n",
+                             hashSize,
+                             sequence.toString());
     message += clashingKeys;
 
     QString title = i18ncp("%1 is the number of shortcuts with which there is a conflict",
-                            "Conflict with Registered Global Shortcut", "Conflict with Registered Global Shortcuts", hashSize);
+                           "Conflict with Registered Global Shortcut",
+                           "Conflict with Registered Global Shortcuts",
+                           hashSize);
 
     return KMessageBox::warningContinueCancel(q, message, title, KGuiItem(i18nc("@action:button", "Reassign"))) == KMessageBox::Continue;
 }
 #endif
 
-
 bool KKeySequenceWidgetPrivate::conflictWithGlobalShortcuts(const QKeySequence &keySequence)
 {
 #ifdef Q_OS_WIN
-    //on windows F12 is reserved by the debugger at all times, so we can't use it for a global shortcut
+    // on windows F12 is reserved by the debugger at all times, so we can't use it for a global shortcut
     if (KKeySequenceWidget::GlobalShortcuts && keySequence.toString().contains(QLatin1String("F12"))) {
         QString title = i18n("Reserved Shortcut");
-        QString message = i18n("The F12 key is reserved on Windows, so cannot be used for a global shortcut.\n"
-                               "Please choose another one.");
+        QString message = i18n(
+            "The F12 key is reserved on Windows, so cannot be used for a global shortcut.\n"
+            "Please choose another one.");
 
-        KMessageBox::sorry(q, message, title);
+        KMessageBox::error(q, message, title);
         return false;
     }
 #endif
 #if HAVE_GLOBALACCEL
-     if (!(checkAgainstShortcutTypes & KKeySequenceWidget::GlobalShortcuts)) {
+    if (!(checkAgainstShortcutTypes & KKeySequenceWidget::GlobalShortcuts)) {
         return false;
     }
     // Global shortcuts are on key+modifier shortcuts. They can clash with
     // each of the keys of a multi key shortcut.
-    QHash<QKeySequence, QList<KGlobalShortcutInfo>> clashing;
-    QString clashingKeys;
+    std::vector<KeyConflictInfo> clashing;
     for (int i = 0; i < keySequence.count(); ++i) {
         QKeySequence keys(keySequence[i]);
         if (!KGlobalAccel::isGlobalShortcutAvailable(keySequence, componentName)) {
-            clashing.insert(keySequence, KGlobalAccel::getGlobalShortcutsByKey(keys));
+            clashing.push_back({keySequence, KGlobalAccel::globalShortcutsByKey(keys)});
         }
     }
-    if (clashing.isEmpty()) {
-        return  false;
+    if (clashing.empty()) {
+        return false;
     }
 
     if (!promptStealGlobalShortcut(clashing, keySequence)) {
@@ -332,9 +334,7 @@ bool KKeySequenceWidgetPrivate::conflictWithGlobalShortcuts(const QKeySequence &
     // error it just silently fails. So be nice because this is
     // most likely the first action that is done in the slot
     // listening to keySequenceChanged().
-    for (int i = 0; i < keySequence.count(); ++i) {
-        KGlobalAccel::stealShortcutSystemwide(keySequence[i]);
-    }
+    KGlobalAccel::stealShortcutSystemwide(keySequence);
     return false;
 #else
     Q_UNUSED(keySequence);
@@ -345,22 +345,23 @@ bool KKeySequenceWidgetPrivate::conflictWithGlobalShortcuts(const QKeySequence &
 bool KKeySequenceWidgetPrivate::promptstealStandardShortcut(KStandardShortcut::StandardShortcut std, const QKeySequence &seq)
 {
     QString title = i18nc("@title:window", "Conflict with Standard Application Shortcut");
-    QString message = i18n("The '%1' key combination is also used for the standard action "
-                           "\"%2\" that some applications use.\n"
-                           "Do you really want to use it as a global shortcut as well?",
-                           seq.toString(QKeySequence::NativeText), KStandardShortcut::label(std));
+    QString message = i18n(
+        "The '%1' key combination is also used for the standard action "
+        "\"%2\" that some applications use.\n"
+        "Do you really want to use it as a global shortcut as well?",
+        seq.toString(QKeySequence::NativeText),
+        KStandardShortcut::label(std));
 
     return KMessageBox::warningContinueCancel(q, message, title, KGuiItem(i18nc("@action:button", "Reassign"))) == KMessageBox::Continue;
 }
 
-
 bool KKeySequenceWidgetPrivate::conflictWithStandardShortcuts(const QKeySequence &seq)
 {
     if (!(checkAgainstShortcutTypes & KKeySequenceWidget::StandardShortcuts)) {
         return false;
     }
     KStandardShortcut::StandardShortcut ssc = KStandardShortcut::find(seq);
-    if (ssc != KStandardShortcut::AccelNone && !promptstealStandardShortcut(ssc, seq))  {
+    if (ssc != KStandardShortcut::AccelNone && !promptstealStandardShortcut(ssc, seq)) {
         return true;
     }
     return false;
@@ -395,7 +396,7 @@ void KKeySequenceWidgetPrivate::updateShortcutDisplay()
     }
 
     if (recorder->isRecording()) {
-        //make it clear that input is still going on
+        // make it clear that input is still going on
         s.append(QLatin1String(" ..."));
     }
 
@@ -404,18 +405,18 @@ void KKeySequenceWidgetPrivate::updateShortcutDisplay()
 }
 
 KKeySequenceWidget::KKeySequenceWidget(QWidget *parent)
-    : QWidget(parent),
-      d(new KKeySequenceWidgetPrivate(this))
+    : QWidget(parent)
+    , d(new KKeySequenceWidgetPrivate(this))
 {
     d->init();
     setFocusProxy(d->keyButton);
     connect(d->keyButton, &QPushButton::clicked, this, &KKeySequenceWidget::captureKeySequence);
     connect(d->clearButton, &QToolButton::clicked, this, &KKeySequenceWidget::clearKeySequence);
 
-    connect(d->recorder, &KeySequenceRecorder::currentKeySequenceChanged, this, [this] {
+    connect(d->recorder, &KKeySequenceRecorder::currentKeySequenceChanged, this, [this] {
         d->updateShortcutDisplay();
     });
-    connect(d->recorder, &KeySequenceRecorder::recordingChanged, this, [this] {
+    connect(d->recorder, &KKeySequenceRecorder::recordingChanged, this, [this] {
         if (!d->recorder->isRecording()) {
             d->doneRecording();
         }
@@ -462,8 +463,8 @@ bool KKeySequenceWidget::isKeySequenceAvailable(const QKeySequence &keySequence)
     if (keySequence.isEmpty()) {
         return true;
     }
-    return !(d->conflictWithLocalShortcuts(keySequence)
-             || d->conflictWithGlobalShortcuts(keySequence)
+    return !(d->conflictWithLocalShortcuts(keySequence) //
+             || d->conflictWithGlobalShortcuts(keySequence) //
              || d->conflictWithStandardShortcuts(keySequence));
 }
 
@@ -477,20 +478,12 @@ void KKeySequenceWidget::setClearButtonShown(bool show)
     d->clearButton->setVisible(show);
 }
 
-#if KXMLGUI_BUILD_DEPRECATED_SINCE(4, 1)
-void KKeySequenceWidget::setCheckActionList(const QList<QAction *> &checkList) // deprecated
-{
-    d->checkList = checkList;
-    Q_ASSERT(d->checkActionCollections.isEmpty()); // don't call this method if you call setCheckActionCollections!
-}
-#endif
-
 void KKeySequenceWidget::setCheckActionCollections(const QList<KActionCollection *> &actionCollections)
 {
     d->checkActionCollections = actionCollections;
 }
 
-//slot
+// slot
 void KKeySequenceWidget::captureKeySequence()
 {
     d->recorder->setWindow(window()->windowHandle());
@@ -502,7 +495,7 @@ QKeySequence KKeySequenceWidget::keySequence() const
     return d->keySequence;
 }
 
-//slot
+// slot
 void KKeySequenceWidget::setKeySequence(const QKeySequence &seq, Validation validate)
 {
     if (d->keySequence == seq) {
@@ -516,26 +509,25 @@ void KKeySequenceWidget::setKeySequence(const QKeySequence &seq, Validation vali
     Q_EMIT keySequenceChanged(seq);
 }
 
-//slot
+// slot
 void KKeySequenceWidget::clearKeySequence()
 {
     setKeySequence(QKeySequence());
 }
 
-//slot
+// slot
 void KKeySequenceWidget::applyStealShortcut()
 {
     QSet<KActionCollection *> changedCollections;
 
-    for (QAction *stealAction : qAsConst(d->stealActions)) {
-
+    for (QAction *stealAction : std::as_const(d->stealActions)) {
         // Stealing a shortcut means setting it to an empty one.
         stealAction->setShortcuts(QList<QKeySequence>());
 
         // The following code will find the action we are about to
         // steal from and save it's actioncollection.
         KActionCollection *parentCollection = nullptr;
-        for (KActionCollection *collection : qAsConst(d->checkActionCollections)) {
+        for (KActionCollection *collection : std::as_const(d->checkActionCollections)) {
             if (collection->actions().contains(stealAction)) {
                 parentCollection = collection;
                 break;
@@ -548,12 +540,26 @@ void KKeySequenceWidget::applyStealShortcut()
         }
     }
 
-    for (KActionCollection *col : qAsConst(changedCollections)) {
+    for (KActionCollection *col : std::as_const(changedCollections)) {
         col->writeSettings();
     }
 
     d->stealActions.clear();
 }
 
+bool KKeySequenceWidget::event(QEvent *ev)
+{
+    constexpr char _highlight[] = "_kde_highlight_neutral";
+
+    if (ev->type() == QEvent::DynamicPropertyChange) {
+        auto dpev = static_cast<QDynamicPropertyChangeEvent *>(ev);
+        if (dpev->propertyName() == _highlight) {
+            d->keyButton->setProperty(_highlight, property(_highlight));
+            return true;
+        }
+    }
+
+    return QWidget::event(ev);
+}
 
 #include "moc_kkeysequencewidget.cpp"
